@@ -1,13 +1,13 @@
-use super::io::*;
-use crate::state::Bundle;
+// use super::io::*;
+// use crate::state::OCA;
 use std::io::Read;
 
 pub type GenericError = Box<dyn std::error::Error + Sync + Send>;
 pub type GenericResult<T> = Result<T, GenericError>;
 
-pub fn load(source: &mut dyn Read) -> GenericResult<()> {
+pub fn load(_source: &mut dyn Read) -> GenericResult<()> {
     /*
-    let v: Bundle = serde_json::from_reader(source)?;
+    let v: OCA = serde_json::from_reader(source)?;
     println!("{:?}", v);
     */
 
